router

package
v1.1.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 14, 2019 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DumbRouter

type DumbRouter struct {
	ServerName  string
	CamoHandler http.Handler
	AddHeaders  map[string]string
}

DumbRouter is a basic, special purpose, http router

func (*DumbRouter) HealthCheckHandler added in v1.1.0

func (dr *DumbRouter) HealthCheckHandler(w http.ResponseWriter, r *http.Request)

HealthCheckHandler is HTTP handler for confirming the backend service is available from an external client, such as a load balancer.

func (*DumbRouter) ServeHTTP

func (dr *DumbRouter) ServeHTTP(w http.ResponseWriter, r *http.Request)

ServeHTTP fulfills the http server interface

func (*DumbRouter) SetHeaders

func (dr *DumbRouter) SetHeaders(w http.ResponseWriter)

SetHeaders sets the headers on the response

Jump to