Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DumbRouter ¶
DumbRouter is a basic, special purpose, http router
func (*DumbRouter) HealthCheckHandler ¶ added in v1.1.0
func (dr *DumbRouter) HealthCheckHandler(w http.ResponseWriter, r *http.Request)
HealthCheckHandler is HTTP handler for confirming the backend service is available from an external client, such as a load balancer.
func (*DumbRouter) ServeHTTP ¶
func (dr *DumbRouter) ServeHTTP(w http.ResponseWriter, r *http.Request)
ServeHTTP fulfills the http server interface
func (*DumbRouter) SetHeaders ¶
func (dr *DumbRouter) SetHeaders(w http.ResponseWriter)
SetHeaders sets the headers on the response
Click to show internal directories.
Click to hide internal directories.